@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2013-2021 The Octave Project Developers
+// Copyright (C) 2013-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -181,6 +181,8 @@ namespace octave
                    const QStringList& button, const QString& defbutton,
                    const QStringList& role);
 
+    ~MessageDialog (void) = default;
+
   private:
 
     void closeEvent (QCloseEvent *)
@@ -205,7 +207,7 @@ namespace octave
                 const QStringList& prompt, const QString& ok_string,
                 const QString& cancel_string);
 
-    ~ListDialog (void);
+    ~ListDialog (void) = default;
 
   signals:
 
@@ -238,6 +240,8 @@ namespace octave
                  const QString& title, const QFloatList& nr,
                  const QFloatList& nc, const QStringList& defaults);
 
+    ~InputDialog (void) = default;
+
   signals:
 
     void finish_input (const QStringList&, int);
@@ -261,6 +265,8 @@ namespace octave
                 const QString& title, const QString& filename,
                 const QString& dirname, const QString& multimode);
 
+    ~FileDialog (void) = default;
+
   signals:
 
     void finish_input (const QStringList&, const QString&, int);
