@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2013-2020 The Octave Project Developers
+// Copyright (C) 2013-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -460,7 +460,7 @@ namespace octave
 
       Cell cval = m_value.cell_value ();
 
-      return edit_display_sub (cval(row,col), role);
+      return edit_display_sub (cval(row, col), role);
     }
 
     bool requires_sub_editor (const QModelIndex& idx) const
@@ -473,7 +473,7 @@ namespace octave
 
       Cell cval = m_value.cell_value ();
 
-      return do_requires_sub_editor_sub (cval(row,col));
+      return do_requires_sub_editor_sub (cval(row, col));
     }
 
     char quote_char (const QModelIndex& idx) const
@@ -506,7 +506,7 @@ namespace octave
 
       Cell cval = m_value.cell_value ();
 
-      return cval(row,col);
+      return cval(row, col);
     }
   };
 
@@ -880,7 +880,7 @@ namespace octave
 
       octave_map m = m_value.map_value ();
 
-      return do_requires_sub_editor_sub (m(row,col));
+      return do_requires_sub_editor_sub (m(row, col));
     }
 
     char quote_char (const QModelIndex& idx) const
@@ -916,7 +916,7 @@ namespace octave
 
       octave_map m = m_value.map_value ();
 
-      return m(row,col);
+      return m(row, col);
     }
   };
 
@@ -954,14 +954,14 @@ namespace octave
   {
     update_description ();
 
-    connect (this, SIGNAL (user_error_signal (const QString&, const QString&)),
-             this, SLOT (user_error (const QString&, const QString&)));
+    connect (this, &variable_editor_model::user_error_signal,
+             this, &variable_editor_model::user_error);
 
-    connect (this, SIGNAL (update_data_signal (const octave_value&)),
-             this, SLOT (update_data (const octave_value&)));
+    connect (this, &variable_editor_model::update_data_signal,
+             this, &variable_editor_model::update_data);
 
-    connect (this, SIGNAL (data_error_signal (const QString&)),
-             this, SLOT (data_error (const QString&)));
+    connect (this, &variable_editor_model::data_error_signal,
+             this, &variable_editor_model::data_error);
 
     if (is_editable ())
       {
@@ -987,7 +987,7 @@ namespace octave
   variable_editor_model::setData (const QModelIndex& idx,
                                   const QVariant& v_user_input, int role)
   {
-    if (role != Qt::EditRole || ! v_user_input.canConvert (QVariant::String)
+    if (role != Qt::EditRole || ! v_user_input.canConvert (QMetaType::QString)
         || ! idx.isValid ())
       return false;
 
@@ -1024,7 +1024,7 @@ namespace octave
     std::string expr = os.str ();
 
     emit interpreter_event
-      ([this, nm, expr, idx] (interpreter& interp)
+      ([=] (interpreter& interp)
        {
          // INTERPRETER THREAD
 
@@ -1173,7 +1173,7 @@ namespace octave
     std::string expr = expr_arg.toStdString ();
 
     emit interpreter_event
-      ([this, expr] (interpreter& interp)
+      ([=] (interpreter& interp)
        {
          // INTERPRETER THREAD
 
@@ -1245,7 +1245,7 @@ namespace octave
   variable_editor_model::update_data_cache (void)
   {
     emit interpreter_event
-      ([this] (interpreter& interp)
+      ([=] (interpreter& interp)
        {
          // INTERPRETER_THREAD
 
