@@ -1,25 +1,27 @@
-/*
-
-Copyright (C) 2007-2018 David Bateman
-Copyright (C) 2009 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2007-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -173,10 +175,10 @@ static void maybe_fill_table (void)
   REGISTER_OP_HANDLER (bsxfun_builtin_or, btyp_bool, boolNDArray, bsxfun_or);
 
   // Register power handlers.
-  bsxfun_handler_table[bsxfun_builtin_power][btyp_double] =
-    do_bsxfun_real_pow<NDArray, ComplexNDArray>;
-  bsxfun_handler_table[bsxfun_builtin_power][btyp_float] =
-    do_bsxfun_real_pow<FloatNDArray, FloatComplexNDArray>;
+  bsxfun_handler_table[bsxfun_builtin_power][btyp_double]
+    = do_bsxfun_real_pow<NDArray, ComplexNDArray>;
+  bsxfun_handler_table[bsxfun_builtin_power][btyp_float]
+    = do_bsxfun_real_pow<FloatNDArray, FloatComplexNDArray>;
 
   REGISTER_OP_HANDLER (bsxfun_builtin_power, btyp_complex, ComplexNDArray,
                        bsxfun_pow);
@@ -318,7 +320,9 @@ update_index (Array<int>& idx, const dim_vector& dv, octave_idx_type i)
     }
 }
 
-DEFMETHOD (bsxfun, interp,args, ,
+OCTAVE_NAMESPACE_BEGIN
+
+DEFMETHOD (bsxfun, interp, args, ,
            doc: /* -*- texinfo -*-
 @deftypefn {} {} bsxfun (@var{f}, @var{A}, @var{B})
 Apply a binary function @var{f} element-by-element to two array arguments
@@ -344,7 +348,7 @@ as the other array.
     {
       std::string name = func.string_value ();
 
-      octave::symbol_table& symtab = interp.get_symbol_table ();
+      symbol_table& symtab = interp.get_symbol_table ();
 
       func = symtab.find_function (name);
 
@@ -410,14 +414,14 @@ as the other array.
           octave_value_list inputs (2);
           inputs(0) = A;
           inputs(1) = B;
-          retval = octave::feval (func, inputs, 1);
+          retval = feval (func, inputs, 1);
         }
       else if (dvc.numel () < 1)
         {
           octave_value_list inputs (2);
           inputs(0) = A.resize (dvc);
           inputs(1) = B.resize (dvc);
-          retval = octave::feval (func, inputs, 1);
+          retval = feval (func, inputs, 1);
         }
       else
         {
@@ -459,7 +463,7 @@ as the other array.
               if (maybe_update_column (Bc, B, dvb, dvc, i, idxB))
                 inputs(1) = Bc;
 
-              octave_value_list tmp = octave::feval (func, inputs, 1);
+              octave_value_list tmp = feval (func, inputs, 1);
 
 #define BSXINIT(T, CLS, EXTRACTOR)                                      \
               (result_type == CLS)                                      \
@@ -485,8 +489,8 @@ as the other array.
                           else
                             {
                               have_ComplexNDArray = true;
-                              result_ComplexNDArray =
-                                tmp(0).complex_array_value ();
+                              result_ComplexNDArray
+                                = tmp(0).complex_array_value ();
                               result_ComplexNDArray.resize (dvc);
                             }
                         }
@@ -495,15 +499,15 @@ as the other array.
                           if (tmp(0).isreal ())
                             {
                               have_FloatNDArray = true;
-                              result_FloatNDArray =
-                                tmp(0).float_array_value ();
+                              result_FloatNDArray
+                                = tmp(0).float_array_value ();
                               result_FloatNDArray.resize (dvc);
                             }
                           else
                             {
                               have_FloatComplexNDArray = true;
-                              result_FloatComplexNDArray =
-                                tmp(0).float_complex_array_value ();
+                              result_FloatComplexNDArray
+                                = tmp(0).float_complex_array_value ();
                               result_FloatComplexNDArray.resize (dvc);
                             }
                         }
@@ -538,14 +542,14 @@ as the other array.
                         {
                           have_NDArray = false;
                           C = result_NDArray;
-                          C = do_cat_op (C, tmp(0), ra_idx);
+                          C = cat_op (C, tmp(0), ra_idx);
                         }
                       else if (tmp(0).isreal ())
                         result_NDArray.insert (tmp(0).array_value (), ra_idx);
                       else
                         {
-                          result_ComplexNDArray =
-                            ComplexNDArray (result_NDArray);
+                          result_ComplexNDArray
+                            = ComplexNDArray (result_NDArray);
                           result_ComplexNDArray.insert
                             (tmp(0).complex_array_value (), ra_idx);
                           have_NDArray = false;
@@ -558,15 +562,15 @@ as the other array.
                         {
                           have_FloatNDArray = false;
                           C = result_FloatNDArray;
-                          C = do_cat_op (C, tmp(0), ra_idx);
+                          C = cat_op (C, tmp(0), ra_idx);
                         }
                       else if (tmp(0).isreal ())
                         result_FloatNDArray.insert
                           (tmp(0).float_array_value (), ra_idx);
                       else
                         {
-                          result_FloatComplexNDArray =
-                            FloatComplexNDArray (result_FloatNDArray);
+                          result_FloatComplexNDArray
+                            = FloatComplexNDArray (result_FloatNDArray);
                           result_FloatComplexNDArray.insert
                             (tmp(0).float_complex_array_value (), ra_idx);
                           have_FloatNDArray = false;
@@ -581,7 +585,7 @@ as the other array.
                         {                                               \
                           have_ ## T = false;                           \
                           C = result_ ## T;                             \
-                          C = do_cat_op (C, tmp(0), ra_idx);            \
+                          C = cat_op (C, tmp(0), ra_idx);       \
                         }                                               \
                       else                                              \
                         result_ ## T .insert (tmp(0). EXTRACTOR ## _array_value (), ra_idx); \
@@ -599,7 +603,7 @@ as the other array.
                   else if BSXLOOP(uint32NDArray, "uint32", uint32)
                   else if BSXLOOP(uint64NDArray, "uint64", uint64)
                   else
-                    C = do_cat_op (C, tmp(0), ra_idx);
+                    C = cat_op (C, tmp(0), ra_idx);
                 }
             }
 
@@ -635,12 +639,12 @@ as the other array.
 %! b = mean (a, 1);
 %! c = mean (a, 2);
 %! f = @minus;
-%!error (bsxfun (f))
-%!error (bsxfun (f, a))
-%!error (bsxfun (a, b))
-%!error (bsxfun (a, b, c))
-%!error (bsxfun (f, a, b, c))
-%!error (bsxfun (f, ones (4, 0), ones (4, 4)))
+%!error bsxfun (f)
+%!error bsxfun (f, a)
+%!error bsxfun (a, b)
+%!error bsxfun (a, b, c)
+%!error bsxfun (f, a, b, c)
+%!error bsxfun (f, ones (4, 0), ones (4, 4))
 %!assert (bsxfun (f, ones (4, 0), ones (4, 1)), zeros (4, 0))
 %!assert (bsxfun (f, ones (1, 4), ones (4, 1)), zeros (4, 4))
 %!assert (bsxfun (f, a, b), a - repmat (b, 4, 1))
@@ -653,12 +657,12 @@ as the other array.
 %! b = mean (a, 1);
 %! c = mean (a, 2);
 %! f = @minus;
-%!error (bsxfun (f))
-%!error (bsxfun (f, a))
-%!error (bsxfun (a, b))
-%!error (bsxfun (a, b, c))
-%!error (bsxfun (f, a, b, c))
-%!error (bsxfun (f, ones (4, 0), ones (4, 4)))
+%!error bsxfun (f)
+%!error bsxfun (f, a)
+%!error bsxfun (a, b)
+%!error bsxfun (a, b, c)
+%!error bsxfun (f, a, b, c)
+%!error bsxfun (f, ones (4, 0), ones (4, 4))
 %!assert (bsxfun (f, ones (4, 0), ones (4, 1)), zeros (4, 0))
 %!assert (bsxfun (f, ones (1, 4), ones (4, 1)), zeros (4, 4))
 %!assert (bsxfun (f, a, b), a - repmat (b, 4, 1))
@@ -671,12 +675,12 @@ as the other array.
 %! b = mean (a, 1);
 %! c = mean (a, 2);
 %! f = @minus;
-%!error (bsxfun (f))
-%!error (bsxfun (f, a))
-%!error (bsxfun (a, b))
-%!error (bsxfun (a, b, c))
-%!error (bsxfun (f, a, b, c))
-%!error (bsxfun (f, ones (4, 0), ones (4, 4)))
+%!error bsxfun (f)
+%!error bsxfun (f, a)
+%!error bsxfun (a, b)
+%!error bsxfun (a, b, c)
+%!error bsxfun (f, a, b, c)
+%!error bsxfun (f, ones (4, 0), ones (4, 4))
 %!assert (bsxfun (f, ones (4, 0), ones (4, 1)), zeros (4, 0))
 %!assert (bsxfun (f, ones (1, 4), ones (4, 1)), zeros (4, 4))
 %!assert (bsxfun (f, a, b), a - repmat (b, 4, 1))
@@ -688,12 +692,12 @@ as the other array.
 %! b = a (1, :);
 %! c = a (:, 1);
 %! f = @(x, y) x == y;
-%!error (bsxfun (f))
-%!error (bsxfun (f, a))
-%!error (bsxfun (a, b))
-%!error (bsxfun (a, b, c))
-%!error (bsxfun (f, a, b, c))
-%!error (bsxfun (f, ones (4, 0), ones (4, 4)))
+%!error bsxfun (f)
+%!error bsxfun (f, a)
+%!error bsxfun (a, b)
+%!error bsxfun (a, b, c)
+%!error bsxfun (f, a, b, c)
+%!error bsxfun (f, ones (4, 0), ones (4, 4))
 %!assert (bsxfun (f, ones (4, 0), ones (4, 1)), zeros (4, 0, "logical"))
 %!assert (bsxfun (f, ones (1, 4), ones (4, 1)), ones (4, 4, "logical"))
 %!assert (bsxfun (f, a, b), a == repmat (b, 4, 1))
@@ -705,7 +709,7 @@ as the other array.
 %! c = mean (a, 2);
 %! d = mean (a, 3);
 %! f = @minus;
-%!error (bsxfun (f, ones ([4, 0, 4]), ones ([4, 4, 4])))
+%!error bsxfun (f, ones ([4, 0, 4]), ones ([4, 4, 4]))
 %!assert (bsxfun (f, ones ([4, 0, 4]), ones ([4, 1, 4])), zeros ([4, 0, 4]))
 %!assert (bsxfun (f, ones ([4, 4, 0]), ones ([4, 1, 1])), zeros ([4, 4, 0]))
 %!assert (bsxfun (f, ones ([1, 4, 4]), ones ([4, 1, 4])), zeros ([4, 4, 4]))
@@ -721,6 +725,10 @@ as the other array.
 %!assert (bsxfun (f, ones ([4, 1, 4, 1]), ones ([1, 4, 1, 4])), zeros ([4, 4, 4, 4]))
 
 %!shared a, b, aa, bb
+%! ## FIXME: Set a known "good" random seed.  See bug #51779.
+%! old_nstate = randn ("state");
+%! restore_nstate = onCleanup (@() randn ("state", old_nstate));
+%! randn ("state", 42); # initialize generator to make behavior reproducible
 %! a = randn (3, 1, 3);
 %! aa = a(:, ones (1, 3), :, ones (1, 3));
 %! b = randn (1, 3, 3, 3);
@@ -754,6 +762,11 @@ as the other array.
 %! int_types = {@int8, @int16, @int32, @int64, ...
 %!              @uint8, @uint16, @uint32, @uint64};
 %!
+%! ## FIXME: Set a known "good" random seed.  See bug #51779.
+%! old_state = rand ("state");
+%! restore_state = onCleanup (@() rand ("state", old_state));
+%! rand ("state", 42);  # initialize generator to make behavior reproducible
+%!
 %! x = rand (3) * 10-5;
 %! y = rand (3,1) * 10-5;
 %!
@@ -784,13 +797,13 @@ as the other array.
 %! endfor
 
 ## Automatic broadcasting with zero length dimensions
-%!assert <*47085> ([1 2 3] .+ zeros (0, 3), zeros (0, 3))
-%!assert <*47085> (rand (3, 3, 1) .+ rand (3, 3, 0), zeros (3, 3, 0))
+%!assert <*47085> ([1 2 3] + zeros (0, 3), zeros (0, 3))
+%!assert <*47085> (rand (3, 3, 1) + rand (3, 3, 0), zeros (3, 3, 0))
 
 ## In-place broadcasting with zero length dimensions
 %!test <*47085>
 %! a = zeros (0, 3);
-%! a .+= [1 2 3];
+%! a += [1 2 3];
 %! assert (a, zeros (0, 3));
 
 %!test <*53179>
@@ -801,3 +814,5 @@ as the other array.
 %! assert (r(:,:,1), repmat (single ([0, 0, 1+i, 1+i]), [4, 1]));
 
 */
+
+OCTAVE_NAMESPACE_END
