@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2021 The Octave Project Developers
+// Copyright (C) 1993-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -84,6 +84,8 @@
 #include "utils.h"
 #include "variables.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 static void
 normalize_fopen_mode (std::string& mode, bool& use_zlib)
 {
@@ -190,7 +192,7 @@ with gnuplot.
   if (args.length () != 1)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   return ovl (streams.remove (args(0), "fclose"));
 }
@@ -206,11 +208,11 @@ Clear the stream state for the file specified by the file descriptor
   if (args.length () != 1)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   int fid = streams.get_file_number (args(0));
 
-  octave::stream os = streams.lookup (fid, "fclear");
+  stream os = streams.lookup (fid, "fclear");
 
   os.clearerr ();
 
@@ -237,20 +239,20 @@ always a good idea to flush the standard output stream before calling
 
   octave_value retval = -1;
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   // FIXME: any way to avoid special case for stdout?
   int fid = streams.get_file_number (args(0));
 
   if (fid == 1)
     {
-      octave::flush_stdout ();
+      flush_stdout ();
 
       retval = 0;
     }
   else
     {
-      octave::stream os = streams.lookup (fid, "fflush");
+      stream os = streams.lookup (fid, "fflush");
 
       retval = os.flush ();
     }
@@ -273,7 +275,8 @@ character.
 
 If there are no more characters to read, @code{fgetl} returns @minus{}1.
 
-To read a line and return the terminating newline see @code{fgets}.
+To read a line and return the terminating newline,
+@pxref{XREFfgets,,@code{fgets}}.
 @seealso{fgets, fscanf, fread, fopen}
 @end deftypefn */)
 {
@@ -284,9 +287,9 @@ To read a line and return the terminating newline see @code{fgets}.
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), who);
+  stream os = streams.lookup (args(0), who);
 
   octave_value len_arg = (nargin == 2) ? args(1) : octave_value ();
 
@@ -315,7 +318,8 @@ character.
 
 If there are no more characters to read, @code{fgets} returns @minus{}1.
 
-To read a line and discard the terminating newline see @code{fgetl}.
+To read a line and discard the terminating newline,
+@pxref{XREFfgetl,,@code{fgetl}}.
 @seealso{fputs, fgetl, fscanf, fread, fopen}
 @end deftypefn */)
 {
@@ -326,9 +330,9 @@ To read a line and discard the terminating newline see @code{fgetl}.
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), who);
+  stream os = streams.lookup (args(0), who);
 
   octave_value len_arg = (nargin == 2) ? args(1) : octave_value ();
 
@@ -368,9 +372,9 @@ Returns the number of lines skipped (end-of-line sequences encountered).
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), who);
+  stream os = streams.lookup (args(0), who);
 
   octave_value count_arg = (nargin == 2) ? args(1) : octave_value ();
 
@@ -384,11 +388,11 @@ Returns the number of lines skipped (end-of-line sequences encountered).
     return ovl ();
 }
 
-static octave::stream
+static stream
 do_stream_open (const std::string& name, const std::string& mode_arg,
                 const std::string& arch, std::string encoding, int& fid)
 {
-  octave::stream retval;
+  stream retval;
 
   fid = -1;
 
@@ -415,22 +419,22 @@ do_stream_open (const std::string& name, const std::string& mode_arg,
 
   std::ios::openmode md = fopen_mode_to_ios_mode (mode);
 
-  octave::mach_info::float_format flt_fmt
-    = octave::mach_info::string_to_float_format (arch);
+  mach_info::float_format flt_fmt
+    = mach_info::string_to_float_format (arch);
 
-  std::string fname = octave::sys::file_ops::tilde_expand (name);
+  std::string fname = sys::file_ops::tilde_expand (name);
 
-  octave::sys::file_stat fs (fname);
+  sys::file_stat fs (fname);
 
   if (! (md & std::ios::out))
-    fname = octave::find_data_file_in_load_path ("fopen", fname);
+    fname = find_data_file_in_load_path ("fopen", fname);
 
   if (! fs.is_dir ())
     {
 #if defined (HAVE_ZLIB)
       if (use_zlib)
         {
-          FILE *fptr = octave::sys::fopen (fname.c_str (), mode.c_str ());
+          FILE *fptr = sys::fopen (fname.c_str (), mode.c_str ());
 
           if (fptr)
             {
@@ -438,8 +442,8 @@ do_stream_open (const std::string& name, const std::string& mode_arg,
 
               gzFile gzf = ::gzdopen (fd, mode.c_str ());
 
-              retval = octave_zstdiostream::create (fname, gzf, fd, md,
-                                                    flt_fmt, encoding);
+              retval = zstdiostream::create (fname, gzf, fd, md, flt_fmt,
+                                             encoding);
             }
           else
             retval.error (std::strerror (errno));
@@ -447,10 +451,9 @@ do_stream_open (const std::string& name, const std::string& mode_arg,
       else
 #endif
         {
-          FILE *fptr = octave::sys::fopen (fname, mode);
+          FILE *fptr = sys::fopen (fname, mode);
 
-          retval = octave_stdiostream::create (fname, fptr, md, flt_fmt,
-                                               encoding);
+          retval = stdiostream::create (fname, fptr, md, flt_fmt, encoding);
 
           if (! fptr)
             retval.error (std::strerror (errno));
@@ -461,12 +464,12 @@ do_stream_open (const std::string& name, const std::string& mode_arg,
   return retval;
 }
 
-static octave::stream
+static stream
 do_stream_open (const octave_value& tc_name, const octave_value& tc_mode,
                 const octave_value& tc_arch, const octave_value& tc_encoding,
                 const char *fcn, int& fid)
 {
-  octave::stream retval;
+  stream retval;
 
   fid = -1;
 
@@ -585,7 +588,8 @@ in a single operation.  This is very efficient and improves performance.
 is immediately performed.  If the write operation must be performed immediately
 after data has been written then the write should be followed by a call to
 @code{fflush} to flush the internal buffer.
-@seealso{fclose, fgets, fgetl, fscanf, fread, fputs, fdisp, fprintf, fwrite, fskipl, fseek, frewind, ftell, feof, ferror, fclear, fflush, freport, umask}
+@seealso{fclose, fgets, fgetl, fscanf, fread, fputs, fdisp, fprintf, fwrite,
+fskipl, fseek, frewind, ftell, feof, ferror, fclear, fflush, freport, umask}
 @end deftypefn */)
 {
   int nargin = args.length ();
@@ -595,7 +599,7 @@ after data has been written then the write should be followed by a call to
 
   octave_value_list retval = ovl (-1.0);
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   if (nargin == 1)
     {
@@ -622,7 +626,7 @@ after data has been written then the write should be followed by a call to
 
   octave_value arch = (nargin > 2) ? args(2) : octave_value ("native");
 
-  octave::input_system& input_sys = interp.get_input_system ();
+  input_system& input_sys = interp.get_input_system ();
   octave_value encoding = (nargin > 3) ? args(3)
                           : octave_value (input_sys.mfile_encoding ());
   if (encoding.string_value () == "system")
@@ -630,8 +634,8 @@ after data has been written then the write should be followed by a call to
 
   int fid = -1;
 
-  octave::stream os = do_stream_open (args(0), mode, arch, encoding, "fopen",
-                                      fid);
+  stream os = do_stream_open (args(0), mode, arch, encoding, "fopen",
+                              fid);
 
   if (os)
     retval = ovl (streams.insert (os), "");
@@ -686,7 +690,7 @@ freport ()
   if (args.length () > 0)
     warning ("freport: ignoring extra arguments");
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   octave_stdout << streams.list_open_files ();
 
@@ -710,9 +714,9 @@ is equivalent to @code{fseek (@var{fid}, 0, SEEK_SET)}.
 
   int result = -1;
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "frewind");
+  stream os = streams.lookup (args(0), "frewind");
 
   result = os.rewind ();
 
@@ -746,9 +750,9 @@ combinations of @var{origin} and @var{offset} can be realized.
   if (nargin < 2 || nargin > 3)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "fseek");
+  stream os = streams.lookup (args(0), "fseek");
 
   octave_value origin_arg = (nargin == 3) ? args(2) : octave_value (-1.0);
 
@@ -766,15 +770,15 @@ beginning of the file specified by file descriptor @var{fid}.
   if (args.length () != 1)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "ftell");
+  stream os = streams.lookup (args(0), "ftell");
 
   return ovl (os.tell ());
 }
 
 static octave_value_list
-printf_internal (octave::interpreter& interp, const std::string& who,
+printf_internal (interpreter& interp, const std::string& who,
                  const octave_value_list& args, int nargout)
 {
   int nargin = args.length ();
@@ -784,10 +788,10 @@ printf_internal (octave::interpreter& interp, const std::string& who,
 
   int result;
 
-  octave::stream os;
+  stream os;
   int fmt_n = 0;
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   if (args(0).is_string ())
     os = streams.lookup (1, who);
@@ -832,7 +836,7 @@ function exactly equivalent to @code{printf}.
 The optional output returns the number of bytes written to the file.
 
 Implementation Note: For compatibility with @sc{matlab}, escape sequences in
-the template string (e.g., @qcode{"@xbackslashchar{}n"} => newline) are
+the template string (e.g., @qcode{"@backslashchar{}n"} => newline) are
 expanded even when the template string is defined with single quotes.
 @seealso{fputs, fdisp, fwrite, fscanf, printf, sprintf, fopen}
 @end deftypefn */)
@@ -855,7 +859,7 @@ complete description of the syntax of the template string.
 @end ifclear
 
 Implementation Note: For compatibility with @sc{matlab}, escape sequences in
-the template string (e.g., @qcode{"@xbackslashchar{}n"} => newline) are
+the template string (e.g., @qcode{"@backslashchar{}n"} => newline) are
 expanded even when the template string is defined with single quotes.
 @seealso{fprintf, sprintf, scanf}
 @end deftypefn */)
@@ -869,15 +873,15 @@ expanded even when the template string is defined with single quotes.
 }
 
 static octave_value_list
-puts_internal (octave::interpreter& interp, const std::string& who,
+puts_internal (interpreter& interp, const std::string& who,
                const octave_value_list& args)
 {
   if (args.length () != 2)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), who);
+  stream os = streams.lookup (args(0), who);
 
   return ovl (os.puts (args(1), who));
 }
@@ -932,7 +936,7 @@ sized string as an argument, Octave's @code{sprintf} function returns the
 string, automatically sized to hold all of the items converted.
 
 Implementation Note: For compatibility with @sc{matlab}, escape sequences in
-the template string (e.g., @qcode{"@xbackslashchar{}n"} => newline) are
+the template string (e.g., @qcode{"@backslashchar{}n"} => newline) are
 expanded even when the template string is defined with single quotes.
 @seealso{printf, fprintf, sscanf}
 @end deftypefn */)
@@ -944,13 +948,13 @@ expanded even when the template string is defined with single quotes.
   if (nargin == 0)
     print_usage ();
 
-  // We don't use octave_ostrstream::create here because need direct
+  // We don't use ostrstream::create here because need direct
   // access to the OSTR object so that we can extract a string object
   // from it to return.
-  octave_ostrstream *ostr = new octave_ostrstream ();
+  ostrstream *ostr = new ostrstream ();
 
-  // The octave::stream destructor will delete OSTR for us.
-  octave::stream os (ostr);
+  // The stream destructor will delete OSTR for us.
+  stream os (ostr);
 
   if (! os.is_valid ())
     error ("%s: unable to create output buffer", who.c_str ());
@@ -985,7 +989,7 @@ expanded even when the template string is defined with single quotes.
 }
 
 static octave_value_list
-scanf_internal (octave::interpreter& interp, const std::string& who,
+scanf_internal (interpreter& interp, const std::string& who,
                 const octave_value_list& args)
 {
   int nargin = args.length ();
@@ -995,9 +999,9 @@ scanf_internal (octave::interpreter& interp, const std::string& who,
 
   octave_value_list retval;
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), who);
+  stream os = streams.lookup (args(0), who);
 
   if (! args(1).is_string ())
     error ("%s: format TEMPLATE must be a string", who.c_str ());
@@ -1117,7 +1121,7 @@ character to be read is returned in @var{pos}.
 
   std::string data = get_scan_string_data (args(0), who);
 
-  octave::stream os = octave_istrstream::create (data);
+  stream os = istrstream::create (data);
 
   if (! os.is_valid ())
     error ("%s: unable to create temporary input buffer", who.c_str ());
@@ -1178,26 +1182,26 @@ It is currently not useful to call @code{scanf} in interactive programs.
 }
 
 static octave_value_list
-textscan_internal (octave::interpreter& interp, const std::string& who,
+textscan_internal (interpreter& interp, const std::string& who,
                    const octave_value_list& args)
 {
   if (args.length () < 1)
     print_usage (who);
 
-  octave::stream os;
+  stream os;
 
   if (args(0).is_string ())
     {
       std::string data = get_scan_string_data (args(0), who);
 
-      os = octave_istrstream::create (data);
+      os = istrstream::create (data);
 
       if (! os.is_valid ())
         error ("%s: unable to create temporary input buffer", who.c_str ());
     }
   else
     {
-      octave::stream_list& streams = interp.get_stream_list ();
+      stream_list& streams = interp.get_stream_list ();
 
       os = streams.lookup (args(0), who);
     }
@@ -1216,7 +1220,7 @@ textscan_internal (octave::interpreter& interp, const std::string& who,
       fmt = args(1).string_value ();
 
       if (args(1).is_sq_string ())
-        fmt = octave::do_string_escapes (fmt);
+        fmt = do_string_escapes (fmt);
 
       nskip++;
     }
@@ -1444,12 +1448,12 @@ example), then the default is zero.
 @item @qcode{"EndOfLine"}
 @var{value} can be either an empty or one character specifying the
 end-of-line character, or the pair
-@qcode{"@xbackslashchar{}r@xbackslashchar{}n"} (CRLF).
+@qcode{"@backslashchar{}r@backslashchar{}n"} (CRLF).
 In the latter case, any of
-@qcode{"@xbackslashchar{}r"}, @qcode{"@xbackslashchar{}n"} or
-@qcode{"@xbackslashchar{}r@xbackslashchar{}n"} is counted as a (single)
+@qcode{"@backslashchar{}r"}, @qcode{"@backslashchar{}n"} or
+@qcode{"@backslashchar{}r@backslashchar{}n"} is counted as a (single)
 newline.  If no value is given,
-@qcode{"@xbackslashchar{}r@xbackslashchar{}n"} is used.
+@qcode{"@backslashchar{}r@backslashchar{}n"} is used.
 @c If set to "" (empty string) EOLs are ignored as delimiters and added
 @c to whitespace.
 
@@ -1487,7 +1491,7 @@ The default value for whitespace is
 @c Note: the next line specifically has a newline which generates a space
 @c       in the output of qcode, but keeps the next line < 80 characters.
 @qcode{"
-@xbackslashchar{}b@xbackslashchar{}r@xbackslashchar{}n@xbackslashchar{}t"}
+@backslashchar{}b@backslashchar{}r@backslashchar{}n@backslashchar{}t"}
 (note the space).  Unless whitespace is set to @qcode{""} (empty) AND at
 least one @qcode{"%s"} format conversion specifier is supplied, a space is
 always part of whitespace.
@@ -1641,8 +1645,10 @@ as the name of the function when reporting errors.
 %! c = textscan (str, "%4f %f", "delimiter", ";", "collectOutput", 1);
 %! assert (c, {[12, 34; 1234, 56789; 7, NaN]});
 
+## FIXME: Not Matlab compatible.  Matlab prioritizes precision over field width
+## so "12.234e+2", when read with "%10.2f %f", yields "12.23" and "4e+2".
 ## Ignore trailing delimiter, but use leading one
-%!test
+%!#test
 %! str = "12.234e+2,34, \n12345.789-9876j,78\n,10|3";
 %! c = textscan (str, "%10.2f %f", "delimiter", ",", "collectOutput", 1,
 %!                    "expChars", "e|");
@@ -2285,7 +2291,46 @@ as the name of the function when reporting errors.
 %! obs = textscan (str, "%q", "delimiter", ",");
 %! assert (obs, { { "a,b"; "c" } });
 
+%!test <*58008>
+%! txt = sprintf ('literal_other_1_1;literal_other_1_2\nliteral_other_2_1;literal_other_2_2\nliteral_other_3_1;literal_other_3_2');
+%! nm1 = textscan (txt, 'literal%s literal%s', 'Delimiter', ';');
+%! assert (nm1{1}, {"_other_1_1" ; "_other_2_1" ; "_other_3_1"});
+%! assert (nm1{2}, {"_other_1_2" ; "_other_2_2" ; "_other_3_2"});
+%! nm2 = textscan (txt, 'literal%s;literal%s', 'Delimiter', ';');
+%! assert (nm1, nm2);
+
+%!test <*57612>
+%! str = sprintf (['101,' '\n' '201,']);
+%! C = textscan (str, '%s%q', 'Delimiter', ',');
+%! assert (size (C), [1, 2]);
+%! assert (C{1}, { "101"; "201" });
+%! assert (C{2}, { ""; "" });
+
+%!test <*57612>
+%! str = sprintf (['101,' '\n' '201,']);
+%! C = textscan (str, '%s%f', 'Delimiter', ',');
+%! assert (size (C), [1, 2]);
+%! assert (C{1}, { "101"; "201" });
+%! assert (C{2}, [ NaN; NaN ]);
+
+%!test <*57612>
+%! str = sprintf (['101,' '\n' '201,']);
+%! C = textscan (str, '%s%d', 'Delimiter', ',');
+%! assert (size (C), [1, 2]);
+%! assert (C{1}, { "101"; "201" });
+%! assert (C{2}, int32 ([ 0; 0 ]));
+
+%!test <*51093>
+%! str = sprintf ('a\t\tb\tc');
+%! C = textscan (str, '%s', 'Delimiter', '\t', 'MultipleDelimsAsOne', false);
+%! assert (C{1}, {'a'; ''; 'b'; 'c'});
+
+%!test <50743>
+%! C = textscan ('5973459727478852968', '%u64');
+%! assert (C{1}, uint64 (5973459727478852968));
+
 */
+
 // These tests have end-comment sequences, so can't just be in a comment
 #if 0
 ## Test unfinished comment
@@ -2322,7 +2367,7 @@ as the name of the function when reporting errors.
 */
 
 static octave_value
-do_fread (octave::stream& os, const octave_value& size_arg,
+do_fread (stream& os, const octave_value& size_arg,
           const octave_value& prec_arg, const octave_value& skip_arg,
           const octave_value& arch_arg, octave_idx_type& count)
 {
@@ -2341,9 +2386,9 @@ do_fread (octave::stream& os, const octave_value& size_arg,
       oct_data_conv::string_to_data_type (prec, block_size,
                                           input_type, output_type);
     }
-  catch (octave::execution_exception& e)
+  catch (execution_exception& ee)
     {
-      error (e, "fread: invalid PRECISION specified");
+      error (ee, "fread: invalid PRECISION specified");
     }
 
   int skip = 0;
@@ -2352,15 +2397,15 @@ do_fread (octave::stream& os, const octave_value& size_arg,
     {
       skip = skip_arg.int_value (true);
     }
-  catch (octave::execution_exception& e)
+  catch (execution_exception& ee)
     {
-      error (e, "fread: SKIP must be an integer");
+      error (ee, "fread: SKIP must be an integer");
     }
 
   std::string arch = arch_arg.xstring_value ("fread: ARCH architecture type must be a string");
 
-  octave::mach_info::float_format flt_fmt
-    = octave::mach_info::string_to_float_format (arch);
+  mach_info::float_format flt_fmt
+    = mach_info::string_to_float_format (arch);
 
   return os.read (size, block_size, input_type, output_type, skip,
                   flt_fmt, count);
@@ -2528,9 +2573,9 @@ The optional return value @var{count} contains the number of elements read.
   if (nargin < 1 || nargin > 5)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "fread");
+  stream os = streams.lookup (args(0), "fread");
 
   octave_value size = lo_ieee_inf_value ();
   octave_value prec = "uint8";
@@ -2564,7 +2609,7 @@ The optional return value @var{count} contains the number of elements read.
 }
 
 static int
-do_fwrite (octave::stream& os, const octave_value& data,
+do_fwrite (stream& os, const octave_value& data,
            const octave_value& prec_arg, const octave_value& skip_arg,
            const octave_value& arch_arg)
 {
@@ -2577,9 +2622,9 @@ do_fwrite (octave::stream& os, const octave_value& data,
     {
       oct_data_conv::string_to_data_type (prec, block_size, output_type);
     }
-  catch (octave::execution_exception& e)
+  catch (execution_exception& ee)
     {
-      error (e, "fwrite: invalid PRECISION specified");
+      error (ee, "fwrite: invalid PRECISION specified");
     }
 
   int skip = 0;
@@ -2588,15 +2633,15 @@ do_fwrite (octave::stream& os, const octave_value& data,
     {
       skip = skip_arg.int_value (true);
     }
-  catch (octave::execution_exception& e)
+  catch (execution_exception& ee)
     {
-      error (e, "fwrite: SKIP must be an integer");
+      error (ee, "fwrite: SKIP must be an integer");
     }
 
   std::string arch = arch_arg.xstring_value ("fwrite: ARCH architecture type must be a string");
 
-  octave::mach_info::float_format flt_fmt
-    = octave::mach_info::string_to_float_format (arch);
+  mach_info::float_format flt_fmt
+    = mach_info::string_to_float_format (arch);
 
   return os.write (data, block_size, output_type, skip, flt_fmt);
 }
@@ -2628,9 +2673,9 @@ are too large to fit in the specified precision.
   if (nargin < 2 || nargin > 5)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "fwrite");
+  stream os = streams.lookup (args(0), "fwrite");
 
   octave_value prec = "uchar";
   octave_value skip = 0;
@@ -2672,9 +2717,9 @@ end-of-file condition.
   if (args.length () != 1)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "feof");
+  stream os = streams.lookup (args(0), "feof");
 
   return ovl (os.eof () ? 1.0 : 0.0);
 }
@@ -2705,9 +2750,9 @@ whether the next operation will result in an error condition.
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
-  octave::stream os = streams.lookup (args(0), "ferror");
+  stream os = streams.lookup (args(0), "ferror");
 
   bool clear = false;
 
@@ -2771,17 +2816,17 @@ endwhile
 
   octave_value retval;
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   if (mode == "r")
     {
-      octave::stream ips = octave_iprocstream::create (name);
+      stream ips = octave_iprocstream::create (name);
 
       retval = streams.insert (ips);
     }
   else if (mode == "w")
     {
-      octave::stream ops = octave_oprocstream::create (name);
+      stream ops = octave_oprocstream::create (name);
 
       retval = streams.insert (ops);
     }
@@ -2803,7 +2848,7 @@ The function @code{fclose} may also be used for the same purpose.
   if (args.length () != 1)
     print_usage ();
 
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   return ovl (streams.remove (args(0), "pclose"));
 }
@@ -2824,7 +2869,7 @@ otherwise the default directory for temporary files is used.
 Programming Note: Because the named file is not opened by @code{tempname},
 it is possible, though relatively unlikely, that it will not be available
 by the time your program attempts to open it.  If this is a concern,
-see @code{tmpfile}.
+@pxref{XREFtmpfile,,@code{tmpfile}}.
 @seealso{mkstemp, tempdir, P_tmpdir, tmpfile}
 @end deftypefn */)
 {
@@ -2838,14 +2883,14 @@ see @code{tmpfile}.
   if (nargin > 0)
     dir = args(0).xstring_value ("tempname: DIR must be a string");
   else
-    dir = octave::sys::env::getenv ("TMPDIR");
+    dir = sys::env::getenv ("TMPDIR");
 
   std::string pfx ("oct-");
 
   if (nargin > 1)
     pfx = args(1).xstring_value ("tempname: PREFIX must be a string");
 
-  return ovl (octave::sys::tempnam (dir, pfx));
+  return ovl (sys::tempnam (dir, pfx));
 }
 
 /*
@@ -2890,7 +2935,7 @@ see @code{tmpfile}.
 %!   assert (tmpdir, tmp_tmpdir);
 %!   assert (tmpfname (1:4), "file");
 %! unwind_protect_cleanup
-%!   rmdir (tmp_tmpdir);
+%!   sts = rmdir (tmp_tmpdir);
 %!   for i = 1:numel (envvar)
 %!     if (isempty (envdir{i}))
 %!       unsetenv (envvar{i});
@@ -2929,16 +2974,16 @@ system-dependent error message.
 
       std::ios::openmode md = fopen_mode_to_ios_mode ("w+b");
 
-      octave::stream s = octave_stdiostream::create (nm, fid, md);
+      stream s = stdiostream::create (nm, fid, md);
 
       if (! s)
         {
           fclose (fid);
 
-          error ("tmpfile: failed to create octave_stdiostream object");
+          error ("tmpfile: failed to create stdiostream object");
         }
 
-      octave::stream_list& streams = interp.get_stream_list ();
+      stream_list& streams = interp.get_stream_list ();
 
       retval = ovl (streams.insert (s), "");
     }
@@ -3008,12 +3053,12 @@ message.
 
           std::ios::openmode md = fopen_mode_to_ios_mode (fopen_mode);
 
-          octave::stream s = octave_stdiostream::create (nm, fid, md);
+          stream s = stdiostream::create (nm, fid, md);
 
           if (! s)
-            error ("mkstemp: failed to create octave_stdiostream object");
+            error ("mkstemp: failed to create stdiostream object");
 
-          octave::stream_list& streams = interp.get_stream_list ();
+          stream_list& streams = interp.get_stream_list ();
 
           retval(0) = streams.insert (s);
           retval(1) = nm;
@@ -3082,7 +3127,7 @@ for the new object are @code{@var{mode} - @var{mask}}.
 
   int oct_mask = convert (mask, 8, 10);
 
-  int status = convert (octave::sys::umask (oct_mask), 10, 8);
+  int status = convert (sys::umask (oct_mask), 10, 8);
 
   if (status >= 0)
     return ovl (status);
@@ -3115,7 +3160,7 @@ environment variable.
   if (args.length () != 0)
     print_usage ();
 
-  return ovl (octave::get_P_tmpdir ());
+  return ovl (get_P_tmpdir ());
 }
 
 // NOTE: the values of SEEK_SET, SEEK_CUR, and SEEK_END have to be
@@ -3174,7 +3219,7 @@ line editing functions.
 @seealso{stdout, stderr}
 @end deftypefn */)
 {
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   return const_value ("stdin", args, streams.stdin_file ());
 }
@@ -3188,7 +3233,7 @@ Data written to the standard output may be filtered through the pager.
 @seealso{stdin, stderr, page_screen_output}
 @end deftypefn */)
 {
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   return const_value ("stdout", args, streams.stdout_file ());
 }
@@ -3203,16 +3248,15 @@ It is useful for error messages and prompts.
 @seealso{stdin, stdout}
 @end deftypefn */)
 {
-  octave::stream_list& streams = interp.get_stream_list ();
+  stream_list& streams = interp.get_stream_list ();
 
   return const_value ("stderr", args, streams.stderr_file ());
 }
 
 // Deprecated variables and functions.
 
-// Deprecated in Octave 6.
-void
-mark_for_deletion (const std::string& file)
+// Remove when corresponding global deprecated function is removed.
+void mark_for_deletion_deprecated (const std::string& file)
 {
   octave::interpreter& interp
     = octave::__get_interpreter__ ("mark_for_deletion");
@@ -3220,12 +3264,13 @@ mark_for_deletion (const std::string& file)
   interp.mark_for_deletion (file);
 }
 
-// Deprecated in Octave 6.
-void
-cleanup_tmp_files (void)
+// Remove when corresponding global deprecated function is removed.
+void cleanup_tmp_files_deprecated (void)
 {
   octave::interpreter& interp
     = octave::__get_interpreter__ ("cleanup_tmp_files");
 
   interp.cleanup_tmp_files ();
 }
+
+OCTAVE_NAMESPACE_END
