@@ -1,28 +1,32 @@
-/*
-
-Copyright (C) 1998-2018 A. S. Hodel
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1998-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 // Generalized eigenvalue balancing via LAPACK
 
-// Author: A. S. Hodel <scotte@eng.auburn.edu>
+// Originally written by A. S. Hodel <scotte@eng.auburn.edu>, but is
+// substantially different with the change to use LAPACK.
 
 #undef DEBUG
 #undef DEBUG_SORT
@@ -35,11 +39,8 @@ along with Octave; see the file COPYING.  If not, see
 #include <cctype>
 #include <cmath>
 
-#if defined (DEBUG) || defined (DEBUG_SORT) || defined (DEBUG_EIG)
-#  include <iostream>
-#  if defined (DEBUG_EIG)
-#    include <iomanip>
-#  endif
+#if defined (DEBUG_EIG)
+#  include <iomanip>
 #endif
 
 #include "f77-fcn.h"
@@ -52,82 +53,15 @@ along with Octave; see the file COPYING.  If not, see
 #include "errwarn.h"
 #include "ovl.h"
 #if defined (DEBUG) || defined (DEBUG_SORT)
+#  include "pager.h"
 #  include "pr-output.h"
 #endif
 
-typedef F77_INT (*sort_function) (const F77_INT& LSIZE,
-                                  const double& ALPHA, const double& BETA,
-                                  const double& S, const double& P);
+OCTAVE_NAMESPACE_BEGIN
 
-extern "C"
-{
-  // Van Dooren's code (netlib.org: toms/590) for reordering GEP.
-  // Only processes Z, not Q.
-  F77_RET_T
-  F77_FUNC (dsubsp, DSUBSP) (const F77_INT& NMAX, const F77_INT& N,
-                             F77_DBLE *A, F77_DBLE *B, F77_DBLE *Z,
-                             sort_function, const F77_DBLE& EPS,
-                             F77_INT& NDIM, F77_INT& FAIL, F77_INT *IND);
-}
+// FIXME: Matlab does not produce lambda as the first output argument.
+// Compatibility problem?
 
-// fcrhp, fin, fout, folhp:
-// Routines for ordering of generalized eigenvalues.
-// Return 1 if test is passed, 0 otherwise.
-//   fin:  |lambda| < 1
-//   fout: |lambda| >= 1
-//   fcrhp: real(lambda) >= 0
-//   folhp: real(lambda) < 0
-
-static F77_INT
-fcrhp (const F77_INT& lsize, const double& alpha, const double& beta,
-       const double& s, const double&)
-{
-  if (lsize == 1)
-    return (alpha * beta >= 0 ? 1 : -1);
-  else
-    return (s >= 0 ? 1 : -1);
-}
-
-static F77_INT
-fin (const F77_INT& lsize, const double& alpha, const double& beta,
-     const double&, const double& p)
-{
-  F77_INT retval;
-
-  if (lsize == 1)
-    retval = (std::abs (alpha) < std::abs (beta) ? 1 : -1);
-  else
-    retval = (std::abs (p) < 1 ? 1 : -1);
-
-#if defined (DEBUG)
-  std::cout << "qz: fin: retval=" << retval << std::endl;
-#endif
-
-  return retval;
-}
-
-static F77_INT
-folhp (const F77_INT& lsize, const double& alpha, const double& beta,
-       const double& s, const double&)
-{
-  if (lsize == 1)
-    return (alpha * beta < 0 ? 1 : -1);
-  else
-    return (s < 0 ? 1 : -1);
-}
-
-static F77_INT
-fout (const F77_INT& lsize, const double& alpha, const double& beta,
-      const double&, const double& p)
-{
-  if (lsize == 1)
-    return (std::abs (alpha) >= std::abs (beta) ? 1 : -1);
-  else
-    return (std::abs (p) >= 1 ? 1 : -1);
-}
-
-//FIXME: Matlab does not produce lambda as the first output argument.
-//       Compatibility problem?
 DEFUN (qz, args, nargout,
        doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{lambda} =} qz (@var{A}, @var{B})
@@ -165,18 +99,18 @@ $\lambda.$
 Compute QZ@tie{}decomposition, generalized eigenvectors, and generalized
 eigenvalues.
 @tex
+$$ AA = Q^T AZ, BB = Q^T BZ $$
 $$ AV = BV{ \rm diag }(\lambda) $$
 $$ W^T A = { \rm diag }(\lambda)W^T B $$
-$$ AA = Q^T AZ, BB = Q^T BZ $$
 @end tex
 @ifnottex
 
 @example
 @group
 
+@var{AA} = @var{Q} * @var{A} * @var{Z}, @var{BB} = @var{Q} * @var{B} * @var{Z}
 @var{A} * @var{V} = @var{B} * @var{V} * diag (@var{lambda})
 @var{W}' * @var{A} = diag (@var{lambda}) * @var{W}' * @var{B}
-@var{AA} = @var{Q} * @var{A} * @var{Z}, @var{BB} = @var{Q} * @var{B} * @var{Z}
 
 @end group
 @end example
@@ -230,17 +164,17 @@ half-plane
 @end enumerate
 
 Note: @code{qz} performs permutation balancing, but not scaling
-(@pxref{XREFbalance,,balance}), which may be lead to less accurate results than
-@code{eig}.  The order of output arguments was selected for compatibility with
-@sc{matlab}.
-@seealso{eig, balance, lu, chol, hess, qr, qzhess, schur, svd}
+(@pxref{XREFbalance,,@code{balance}}), which may be lead to less accurate
+results than @code{eig}.  The order of output arguments was selected for
+compatibility with @sc{matlab}.
+@seealso{eig, gsvd, balance, chol, hess, lu, qr, qzhess, schur}
 @end deftypefn */)
 {
   int nargin = args.length ();
 
 #if defined (DEBUG)
-  std::cout << "qz: nargin = " << nargin
-            << ", nargout = " << nargout << std::endl;
+  octave_stdout << "qz: nargin = " << nargin
+                << ", nargout = " << nargout << std::endl;
 #endif
 
   if (nargin < 2 || nargin > 3 || nargout > 7)
@@ -250,12 +184,12 @@ Note: @code{qz} performs permutation balancing, but not scaling
     error ("qz: invalid number of output arguments for form 3 call");
 
 #if defined (DEBUG)
-  std::cout << "qz: determine ordering option" << std::endl;
+  octave_stdout << "qz: determine ordering option" << std::endl;
 #endif
 
   // Determine ordering option.
-  // declared volatile to avoid compiler warnings about long jumps vforks.
-  volatile char ord_job = 'N';
+
+  char ord_job = 'N';
   double safmin = 0.0;
 
   if (nargin == 3)
@@ -278,9 +212,9 @@ Note: @code{qz} performs permutation balancing, but not scaling
                                    F77_CHAR_ARG_LEN (1));
 
 #if defined (DEBUG_EIG)
-      std::cout << "qz: initial value of safmin="
-                << setiosflags (std::ios::scientific)
-                << safmin << std::endl;
+      octave_stdout << "qz: initial value of safmin="
+                    << setiosflags (std::ios::scientific)
+                    << safmin << std::endl;
 #endif
 
       // Some machines (e.g., DEC alpha) get safmin = 0;
@@ -288,7 +222,8 @@ Note: @code{qz} performs permutation balancing, but not scaling
       if (safmin == 0)
         {
 #if defined (DEBUG_EIG)
-          std::cout << "qz: DANGER WILL ROBINSON: safmin is 0!" << std::endl;
+          octave_stdout << "qz: DANGER WILL ROBINSON: safmin is 0!"
+                        << std::endl;
 #endif
 
           F77_FUNC (xdlamch, XDLAMCH) (F77_CONST_CHAR_ARG2 ("E", 1),
@@ -296,23 +231,24 @@ Note: @code{qz} performs permutation balancing, but not scaling
                                        F77_CHAR_ARG_LEN (1));
 
 #if defined (DEBUG_EIG)
-          std::cout << "qz: safmin set to "
-                    << setiosflags (std::ios::scientific)
-                    << safmin << std::endl;
+          octave_stdout << "qz: safmin set to "
+                        << setiosflags (std::ios::scientific)
+                        << safmin << std::endl;
 #endif
         }
     }
 
 #if defined (DEBUG)
-  std::cout << "qz: check matrix A" << std::endl;
+  octave_stdout << "qz: check matrix A" << std::endl;
 #endif
 
   // Matrix A: check dimensions.
-  F77_INT nn = octave::to_f77_int (args(0).rows ());
-  F77_INT nc = octave::to_f77_int (args(0).columns ());
+  F77_INT nn = to_f77_int (args(0).rows ());
+  F77_INT nc = to_f77_int (args(0).columns ());
 
 #if defined (DEBUG)
-  std::cout << "Matrix A dimensions: (" << nn << ',' << nc << ')' << std::endl;
+  octave_stdout << "Matrix A dimensions: (" << nn << ',' << nc << ')'
+                << std::endl;
 #endif
 
   if (args(0).isempty ())
@@ -333,15 +269,15 @@ Note: @code{qz} performs permutation balancing, but not scaling
     aa = args(0).matrix_value ();
 
 #if defined (DEBUG)
-  std::cout << "qz: check matrix B" << std::endl;
+  octave_stdout << "qz: check matrix B" << std::endl;
 #endif
 
   // Extract argument 2 (bb, or cbb if complex).
-  F77_INT b_nr = octave::to_f77_int (args(1).rows ());
-  F77_INT b_nc = octave::to_f77_int (args(1).columns ());
+  F77_INT b_nr = to_f77_int (args(1).rows ());
+  F77_INT b_nc = to_f77_int (args(1).columns ());
 
   if (nn != b_nc || nn != b_nr)
-    err_nonconformant ();
+    ::err_nonconformant ();
 
   Matrix bb;
   ComplexMatrix cbb;
@@ -353,9 +289,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
 
   // Both matrices loaded, now check whether to calculate complex or real val.
 
-  // declared volatile to avoid compiler warnings about long jumps vforks.
-  volatile bool complex_case
-    = (args(0).iscomplex () || args(1).iscomplex ());
+  bool complex_case = (args(0).iscomplex () || args(1).iscomplex ());
 
   if (nargin == 3 && complex_case)
     error ("qz: cannot re-order complex qz decomposition");
@@ -363,10 +297,10 @@ Note: @code{qz} performs permutation balancing, but not scaling
   // First, declare variables used in both the real and complex cases.
   // FIXME: There are a lot of excess variables declared.
   //        Probably a better way to handle this.
-  Matrix QQ (nn,nn), ZZ (nn,nn), VR (nn,nn), VL (nn,nn);
+  Matrix QQ (nn, nn), ZZ (nn, nn), VR (nn, nn), VL (nn, nn);
   RowVector alphar (nn), alphai (nn), betar (nn);
   ComplexRowVector xalpha (nn), xbeta (nn);
-  ComplexMatrix CQ (nn,nn), CZ (nn,nn), CVR (nn,nn), CVL (nn,nn);
+  ComplexMatrix CQ (nn, nn), CZ (nn, nn), CVR (nn, nn), CVL (nn, nn);
   F77_INT ilo, ihi, info;
   char comp_q = (nargout >= 3 ? 'V' : 'N');
   char comp_z = ((nargout >= 4 || nargin == 3)? 'V' : 'N');
@@ -380,8 +314,8 @@ Note: @code{qz} performs permutation balancing, but not scaling
       std::fill_n (ZZptr, ZZ.numel (), 0.0);
       for (F77_INT i = 0; i < nn; i++)
         {
-          QQ(i,i) = 1.0;
-          ZZ(i,i) = 1.0;
+          QQ(i, i) = 1.0;
+          ZZ(i, i) = 1.0;
         }
     }
 
@@ -393,8 +327,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
     {
 #if defined (DEBUG)
       if (comp_q == 'V')
-        std::cout << "qz: performing balancing; CQ=" << std::endl
-                  << CQ << std::endl;
+        octave_stdout << "qz: performing balancing; CQ =\n" << CQ << std::endl;
 #endif
       if (args(0).isreal ())
         caa = ComplexMatrix (aa);
@@ -420,8 +353,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
     {
 #if defined (DEBUG)
       if (comp_q == 'V')
-        std::cout << "qz: performing balancing; QQ=" << std::endl
-                  << QQ << std::endl;
+        octave_stdout << "qz: performing balancing; QQ =\n" << QQ << std::endl;
 #endif
 
       F77_XFCN (dggbal, DGGBAL,
@@ -450,7 +382,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
 
 #if defined (DEBUG)
       if (comp_q == 'V')
-        std::cout << "qz: balancing done; QQ=" << std::endl << QQ << std::endl;
+        octave_stdout << "qz: balancing done; QQ =\n" << QQ << std::endl;
 #endif
     }
 
@@ -467,7 +399,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
 
 #if defined (DEBUG)
       if (comp_z == 'V')
-        std::cout << "qz: balancing done; ZZ=" << std::endl << ZZ << std::endl;
+        octave_stdout << "qz: balancing done; ZZ=\n" << ZZ << std::endl;
 #endif
     }
 #endif
@@ -479,7 +411,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
       // Complex case.
 
       // The QR decomposition of cbb.
-      octave::math::qr<ComplexMatrix> cbqr (cbb);
+      math::qr<ComplexMatrix> cbqr (cbb);
       // The R matrix of QR decomposition for cbb.
       cbb = cbqr.R ();
       // (Q*)caa for following work.
@@ -543,43 +475,43 @@ Note: @code{qz} performs permutation balancing, but not scaling
   else
     {
 #if defined (DEBUG)
-      std::cout << "qz: performing qr decomposition of bb" << std::endl;
+      octave_stdout << "qz: performing qr decomposition of bb" << std::endl;
 #endif
 
       // Compute the QR factorization of bb.
-      octave::math::qr<Matrix> bqr (bb);
+      math::qr<Matrix> bqr (bb);
 
 #if defined (DEBUG)
-      std::cout << "qz: qr (bb) done; now performing qz decomposition"
-                << std::endl;
+      octave_stdout << "qz: qr (bb) done; now performing qz decomposition"
+                    << std::endl;
 #endif
 
       bb = bqr.R ();
 
 #if defined (DEBUG)
-      std::cout << "qz: extracted bb" << std::endl;
+      octave_stdout << "qz: extracted bb" << std::endl;
 #endif
 
       aa = (bqr.Q ()).transpose () * aa;
 
 #if defined (DEBUG)
-      std::cout << "qz: updated aa " << std::endl;
-      std::cout << "bqr.Q () = " << std::endl << bqr.Q () << std::endl;
+      octave_stdout << "qz: updated aa " << std::endl;
+      octave_stdout << "bqr.Q () =\n" << bqr.Q () << std::endl;
 
       if (comp_q == 'V')
-        std::cout << "QQ =" << QQ << std::endl;
+        octave_stdout << "QQ =" << QQ << std::endl;
 #endif
 
       if (comp_q == 'V')
         QQ = QQ * bqr.Q ();
 
 #if defined (DEBUG)
-      std::cout << "qz: precursors done..." << std::endl;
+      octave_stdout << "qz: precursors done..." << std::endl;
 #endif
 
 #if defined (DEBUG)
-      std::cout << "qz: comp_q = " << comp_q << ", comp_z = " << comp_z
-                << std::endl;
+      octave_stdout << "qz: comp_q = " << comp_q << ", comp_z = " << comp_z
+                    << std::endl;
 #endif
 
       // Reduce to generalized Hessenberg form.
@@ -620,8 +552,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
 
 #if defined (DEBUG)
           if (comp_q == 'V')
-            std::cout << "qz: balancing done; QQ=" << std::endl
-                      << QQ << std::endl;
+            octave_stdout << "qz: balancing done; QQ=\n" << QQ << std::endl;
 #endif
         }
 
@@ -638,8 +569,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
 
 #if defined (DEBUG)
           if (comp_z == 'V')
-            std::cout << "qz: balancing done; ZZ=" << std::endl
-                      << ZZ << std::endl;
+            octave_stdout << "qz: balancing done; ZZ=\n" << ZZ << std::endl;
 #endif
         }
 
@@ -653,205 +583,81 @@ Note: @code{qz} performs permutation balancing, but not scaling
         error ("qz: cannot re-order complex QZ decomposition");
 
 #if defined (DEBUG_SORT)
-      std::cout << "qz: ordering eigenvalues: ord_job = "
-                << ord_job << std::endl;
+      octave_stdout << "qz: ordering eigenvalues: ord_job = "
+                    << ord_job << std::endl;
 #endif
 
-      // Declared static to avoid vfork/long jump compiler complaints.
-      static sort_function sort_test;
-      sort_test = nullptr;
+      Array<F77_LOGICAL> select (dim_vector (nn, 1));
 
-      switch (ord_job)
+      for (int j = 0; j < nn; j++)
         {
-        case 'S':
-          sort_test = &fin;
-          break;
+          switch (ord_job)
+            {
+            case 'S':
+              select(j) = alphar(j)*alphar(j) + alphai(j)*alphai(j) < betar(j)*betar(j);
+              break;
 
-        case 'B':
-          sort_test = &fout;
-          break;
+            case 'B':
+              select(j) = alphar(j)*alphar(j) + alphai(j)*alphai(j) >= betar(j)*betar(j);
+              break;
 
-        case '+':
-          sort_test = &fcrhp;
-          break;
+            case '+':
+              select(j) = alphar(j) * betar(j) >= 0;
+              break;
 
-        case '-':
-          sort_test = &folhp;
-          break;
+            case '-':
+              select(j) = alphar(j) * betar(j) < 0;
+              break;
 
-        default:
-          // Invalid order option
-          // (should never happen since options were checked at the top).
-          panic_impossible ();
-          break;
+            default:
+              // Invalid order option
+              // (should never happen since options were checked at the top).
+              panic_impossible ();
+              break;
+            }
         }
 
-      double inf_norm;
+      F77_LOGICAL wantq = 0, wantz = (comp_z == 'V');
+      F77_INT ijob = 0, mm, lrwork3 = 4*nn+16, liwork = nn;
+      F77_DBLE pl, pr;
+      RowVector rwork3(lrwork3);
+      Array<F77_INT> iwork (dim_vector (liwork, 1));
 
-      F77_XFCN (xdlange, XDLANGE,
-                (F77_CONST_CHAR_ARG2 ("I", 1),
-                 nn, nn, aa.data (), nn, work.fortran_vec (), inf_norm
-                 F77_CHAR_ARG_LEN (1)));
-
-      double eps = std::numeric_limits<double>::epsilon () * inf_norm * nn;
+      F77_XFCN (dtgsen, DTGSEN,
+                (ijob, wantq, wantz,
+                 select.fortran_vec (), nn,
+                 aa.fortran_vec (), nn,
+                 bb.fortran_vec (), nn,
+                 alphar.fortran_vec (),
+                 alphai.fortran_vec (),
+                 betar.fortran_vec (),
+                 nullptr, nn,
+                 ZZ.fortran_vec (), nn,
+                 mm,
+                 pl, pr,
+                 nullptr,
+                 rwork3.fortran_vec (), lrwork3,
+                 iwork.fortran_vec (), liwork,
+                 info));
 
 #if defined (DEBUG_SORT)
-      std::cout << "qz: calling dsubsp: aa=" << std::endl;
-      octave_print_internal (std::cout, aa, 0);
-      std::cout << std::endl << "bb="  << std::endl;
-      octave_print_internal (std::cout, bb, 0);
+      octave_stdout << "qz: back from dtgsen: aa =\n";
+      octave_print_internal (octave_stdout, aa);
+      octave_stdout << "\nbb =\n";
+      octave_print_internal (octave_stdout, bb);
       if (comp_z == 'V')
         {
-          std::cout << std::endl << "ZZ="  << std::endl;
-          octave_print_internal (std::cout, ZZ, 0);
+          octave_stdout << "\nZZ =\n";
+          octave_print_internal (octave_stdout, ZZ);
         }
-      std::cout << std::endl;
-      std::cout << "alphar = " << std::endl;
-      octave_print_internal (std::cout, (Matrix) alphar, 0);
-      std::cout << std::endl << "alphai = " << std::endl;
-      octave_print_internal (std::cout, (Matrix) alphai, 0);
-      std::cout << std::endl << "beta = " << std::endl;
-      octave_print_internal (std::cout, (Matrix) betar, 0);
-      std::cout << std::endl;
-#endif
-
-      Array<F77_INT> ind (dim_vector (nn, 1));
-
-      F77_INT ndim, fail;
-
-      F77_XFCN (dsubsp, DSUBSP,
-                (nn, nn, aa.fortran_vec (), bb.fortran_vec (),
-                 ZZ.fortran_vec (), sort_test, eps, ndim, fail,
-                 ind.fortran_vec ()));
-
-#if defined (DEBUG)
-      std::cout << "qz: back from dsubsp: aa=" << std::endl;
-      octave_print_internal (std::cout, aa, 0);
-      std::cout << std::endl << "bb="  << std::endl;
-      octave_print_internal (std::cout, bb, 0);
-      if (comp_z == 'V')
-        {
-          std::cout << std::endl << "ZZ="  << std::endl;
-          octave_print_internal (std::cout, ZZ, 0);
-        }
-      std::cout << std::endl;
-#endif
-
-      // Manually update alphar, alphai, betar.
-      static F77_INT j;
-
-      j = 0;
-      while (j < nn)
-        {
-#if defined (DEBUG_EIG)
-          std::cout << "computing gen eig #" << j << std::endl;
-#endif
-
-          // Number of zeros in this block.
-          static F77_INT zcnt;
-
-          if (j == (nn-1))
-            zcnt = 1;
-          else if (aa(j+1,j) == 0)
-            zcnt = 1;
-          else zcnt = 2;
-
-          if (zcnt == 1)
-            {
-              // Real zero.
-#if defined (DEBUG_EIG)
-              std::cout << "  single gen eig:" << std::endl;
-              std::cout << "  alphar(" << j << ") = " << aa(j,j)
-                        << std::endl;
-              std::cout << "  betar(" << j << ") = " << bb(j,j)
-                        << std::endl;
-              std::cout << "  alphai(" << j << ") = 0" << std::endl;
-#endif
-
-              alphar(j) = aa(j,j);
-              alphai(j) = 0;
-              betar(j) = bb(j,j);
-            }
-          else
-            {
-              // Complex conjugate pair.
-#if defined (DEBUG_EIG)
-              std::cout << "qz: calling dlag2:" << std::endl;
-              std::cout << "safmin="
-                        << setiosflags (std::ios::scientific)
-                        << safmin << std::endl;
-
-              for (F77_INT idr = j; idr <= j+1; idr++)
-                {
-                  for (F77_INT idc = j; idc <= j+1; idc++)
-                    {
-                      std::cout << "aa(" << idr << ',' << idc << ")="
-                                << aa(idr,idc) << std::endl;
-                      std::cout << "bb(" << idr << ',' << idc << ")="
-                                << bb(idr,idc) << std::endl;
-                    }
-                }
-#endif
-
-              // FIXME: probably should be using
-              // fortran_vec instead of &aa(j,j) here.
-
-              double scale1, scale2, wr1, wr2, wi;
-              const double *aa_ptr = aa.data () + j * nn + j;
-              const double *bb_ptr = bb.data () + j * nn + j;
-              F77_XFCN (dlag2, DLAG2,
-                        (aa_ptr, nn, bb_ptr, nn, safmin,
-                         scale1, scale2, wr1, wr2, wi));
-
-#if defined (DEBUG_EIG)
-              std::cout << "dlag2 returns: scale1=" << scale1
-                        << "\tscale2=" << scale2 << std::endl
-                        << "\twr1=" << wr1 << "\twr2=" << wr2
-                        << "\twi=" << wi << std::endl;
-#endif
-
-              // Just to be safe, check if it's a real pair.
-              if (wi == 0)
-                {
-                  alphar(j) = wr1;
-                  alphai(j) = 0;
-                  betar(j) = scale1;
-                  alphar(j+1) = wr2;
-                  alphai(j+1) = 0;
-                  betar(j+1) = scale2;
-                }
-              else
-                {
-                  alphar(j) = alphar(j+1) = wr1;
-                  alphai(j) = -(alphai(j+1) = wi);
-                  betar(j)  = betar(j+1) = scale1;
-                }
-            }
-
-          // Advance past this block.
-          j += zcnt;
-        }
-
-#if defined (DEBUG_SORT)
-      std::cout << "qz: back from dsubsp: aa=" << std::endl;
-      octave_print_internal (std::cout, aa, 0);
-      std::cout << std::endl << "bb="  << std::endl;
-      octave_print_internal (std::cout, bb, 0);
-
-      if (comp_z == 'V')
-        {
-          std::cout << std::endl << "ZZ="  << std::endl;
-          octave_print_internal (std::cout, ZZ, 0);
-        }
-      std::cout << std::endl << "qz: ndim=" << ndim << std::endl
-                << "fail=" << fail << std::endl;
-      std::cout << "alphar = " << std::endl;
-      octave_print_internal (std::cout, (Matrix) alphar, 0);
-      std::cout << std::endl << "alphai = " << std::endl;
-      octave_print_internal (std::cout, (Matrix) alphai, 0);
-      std::cout << std::endl << "beta = " << std::endl;
-      octave_print_internal (std::cout, (Matrix) betar, 0);
-      std::cout << std::endl;
+      octave_stdout << "\nqz: info=" << info;
+      octave_stdout << "\nalphar =\n";
+      octave_print_internal (octave_stdout, Matrix (alphar));
+      octave_stdout << "\nalphai =\n";
+      octave_print_internal (octave_stdout, Matrix (alphai));
+      octave_stdout << "\nbeta =\n";
+      octave_print_internal (octave_stdout, Matrix (betar));
+      octave_stdout << std::endl;
 #endif
     }
 
@@ -872,18 +678,19 @@ Note: @code{qz} performs permutation balancing, but not scaling
       else
         {
 #if defined (DEBUG)
-          std::cout << "qz: computing generalized eigenvalues" << std::endl;
+          octave_stdout << "qz: computing generalized eigenvalues" << std::endl;
 #endif
 
           // Return finite generalized eigenvalues.
           ComplexColumnVector tmp (nn);
 
-          F77_INT cnt = 0;
           for (F77_INT i = 0; i < nn; i++)
-            if (betar(i) != 0)
-              tmp(cnt++) = Complex (alphar(i), alphai(i)) / betar(i);
-
-          tmp.resize (cnt);  // Trim vector to number of return values
+            {
+              if (betar(i) != 0)
+                tmp(i) = Complex (alphar(i), alphai(i)) / betar(i);
+              else
+                tmp(i) = numeric_limits<double>::Inf ();
+            }
 
           gev = tmp;
         }
@@ -922,7 +729,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
       else
         {
 #if defined (DEBUG)
-          std::cout << "qz: computing generalized eigenvectors" << std::endl;
+          octave_stdout << "qz: computing generalized eigenvectors" << std::endl;
 #endif
 
           VL = QQ;
@@ -953,18 +760,18 @@ Note: @code{qz} performs permutation balancing, but not scaling
               if (j == (nn-1))
                 // Single column.
                 cinc = 1;
-              else if (aa(j+1,j) == 0)
+              else if (aa(j+1, j) == 0)
                 cinc = 1;
 
               // Now copy the eigenvector (s) to CVR, CVL.
               if (cinc == 1)
                 {
                   for (F77_INT i = 0; i < nn; i++)
-                    CVR(i,j) = VR(i,j);
+                    CVR(i, j) = VR(i, j);
 
                   if (side == 'B')
                     for (F77_INT i = 0; i < nn; i++)
-                      CVL(i,j) = VL(i,j);
+                      CVL(i, j) = VL(i, j);
                 }
               else
                 {
@@ -972,15 +779,15 @@ Note: @code{qz} performs permutation balancing, but not scaling
 
                   for (F77_INT i = 0; i < nn; i++)
                     {
-                      CVR(i,j) = Complex (VR(i,j), VR(i,j+1));
-                      CVR(i,j+1) = Complex (VR(i,j), -VR(i,j+1));
+                      CVR(i, j) = Complex (VR(i, j), VR(i, j+1));
+                      CVR(i, j+1) = Complex (VR(i, j), -VR(i, j+1));
                     }
 
                   if (side == 'B')
                     for (F77_INT i = 0; i < nn; i++)
                       {
-                        CVL(i,j) = Complex (VL(i,j), VL(i,j+1));
-                        CVL(i,j+1) = Complex (VL(i,j), -VL(i,j+1));
+                        CVL(i, j) = Complex (VL(i, j), VL(i, j+1));
+                        CVL(i, j+1) = Complex (VL(i, j), -VL(i, j+1));
                       }
                 }
 
@@ -1012,9 +819,9 @@ Note: @code{qz} performs permutation balancing, but not scaling
       if (nargin == 3)
         {
 #if defined (DEBUG)
-          std::cout << "qz: sort: retval(3) = gev = " << std::endl;
-          octave_print_internal (std::cout, ComplexMatrix (gev));
-          std::cout << std::endl;
+          octave_stdout << "qz: sort: retval(3) = gev =\n";
+          octave_print_internal (octave_stdout, ComplexMatrix (gev));
+          octave_stdout << std::endl;
 #endif
           retval(3) = gev;
         }
@@ -1049,11 +856,11 @@ Note: @code{qz} performs permutation balancing, but not scaling
         if (complex_case)
           {
 #if defined (DEBUG)
-            std::cout << "qz: retval(1) = cbb = " << std::endl;
-            octave_print_internal (std::cout, cbb, 0);
-            std::cout << std::endl << "qz: retval(0) = caa = " <<std::endl;
-            octave_print_internal (std::cout, caa, 0);
-            std::cout << std::endl;
+            octave_stdout << "qz: retval(1) = cbb =\n";
+            octave_print_internal (octave_stdout, cbb);
+            octave_stdout << "\nqz: retval(0) = caa =\n";
+            octave_print_internal (octave_stdout, caa);
+            octave_stdout << std::endl;
 #endif
             retval(1) = cbb;
             retval(0) = caa;
@@ -1061,11 +868,11 @@ Note: @code{qz} performs permutation balancing, but not scaling
         else
           {
 #if defined (DEBUG)
-            std::cout << "qz: retval(1) = bb = " << std::endl;
-            octave_print_internal (std::cout, bb, 0);
-            std::cout << std::endl << "qz: retval(0) = aa = " <<std::endl;
-            octave_print_internal (std::cout, aa, 0);
-            std::cout << std::endl;
+            octave_stdout << "qz: retval(1) = bb =\n";
+            octave_print_internal (octave_stdout, bb);
+            octave_stdout << "\nqz: retval(0) = aa =\n";
+            octave_print_internal (octave_stdout, aa);
+            octave_stdout << std::endl;
 #endif
             retval(1) = bb;
             retval(0) = aa;
@@ -1076,7 +883,7 @@ Note: @code{qz} performs permutation balancing, but not scaling
     case 1:
     case 0:
 #if defined (DEBUG)
-      std::cout << "qz: retval(0) = gev = " << gev << std::endl;
+      octave_stdout << "qz: retval(0) = gev = " << gev << std::endl;
 #endif
       retval(0) = gev;
       break;
@@ -1087,34 +894,34 @@ Note: @code{qz} performs permutation balancing, but not scaling
     }
 
 #if defined (DEBUG)
-  std::cout << "qz: exiting (at long last)" << std::endl;
+  octave_stdout << "qz: exiting (at long last)" << std::endl;
 #endif
 
   return retval;
 }
 
 /*
-%!shared a, b, c
-%! a = [1 2; 0 3];
-%! b = [1 0; 0 0];
-%! c = [0 1; 0 0];
-%!assert (qz (a,b), 1)
-%!assert (isempty (qz (a,c)))
+%!test
+%! A = [1 2; 0 3];
+%! B = [1 0; 0 0];
+%! C = [0 1; 0 0];
+%! assert (qz (A,B), [1; Inf]);
+%! assert (qz (A,C), [Inf; Inf]);
 
 ## Example 7.7.3 in Golub & Van Loan
 %!test
 %! a = [ 10  1  2;
 %!        1  2 -1;
-%!        1  1  2];
-%! b = reshape (1:9,3,3);
+%!        1  1  2 ];
+%! b = reshape (1:9, 3,3);
 %! [aa, bb, q, z, v, w, lambda] = qz (a, b);
-%! sz = length (lambda);
-%! observed = (b * v * diag ([lambda;0])) (:, 1:sz);
-%! assert ((a*v)(:, 1:sz), observed, norm (observed) * 1e-14);
-%! observed = (diag ([lambda;0]) * w' * b) (1:sz, :);
-%! assert ((w'*a)(1:sz, :) , observed, norm (observed) * 1e-13);
 %! assert (q * a * z, aa, norm (aa) * 1e-14);
 %! assert (q * b * z, bb, norm (bb) * 1e-14);
+%! is_finite = abs (lambda) < 1 / eps (max (a(:)));
+%! observed = (b * v * diag (lambda))(:,is_finite);
+%! assert (observed, (a*v)(:,is_finite), norm (observed) * 1e-14);
+%! observed = (diag (lambda) * w' * b)(is_finite,:);
+%! assert (observed, (w'*a)(is_finite,:), norm (observed) * 1e-13);
 
 %!test
 %! A = [0, 0, -1, 0; 1, 0, 0, 0; -1, 0, -2, -1; 0, -1, 1, 0];
@@ -1122,4 +929,28 @@ Note: @code{qz} performs permutation balancing, but not scaling
 %! [AA, BB, Q, Z1] = qz (A, B);
 %! [AA, BB, Z2] = qz (A, B, "-");
 %! assert (Z1, Z2);
+
+%!test
+%! A = [ -1.03428  0.24929  0.43205 -0.12860;
+%!        1.16228  0.27870  2.12954  0.69250;
+%!       -0.51524 -0.34939 -0.77820  2.13721;
+%!       -1.32941  2.11870  0.72005  1.00835 ];
+%! B = [  1.407302 -0.632956 -0.360628  0.068534;
+%!        0.149898  0.298248  0.991777  0.023652;
+%!        0.169281 -0.405205 -1.775834  1.511730;
+%!        0.717770  1.291390 -1.766607 -0.531352 ];
+%! [AA, BB, Z, lambda] = qz (A, B, "+");
+%! assert (all (real (lambda(1:3)) >= 0));
+%! assert (real (lambda(4) < 0));
+%! [AA, BB, Z, lambda] = qz (A, B, "-");
+%! assert (real (lambda(1) < 0));
+%! assert (all (real (lambda(2:4)) >= 0));
+%! [AA, BB, Z, lambda] = qz (A, B, "B");
+%! assert (all (abs (lambda(1:3)) >= 1));
+%! assert (abs (lambda(4) < 1));
+%! [AA, BB, Z, lambda] = qz (A, B, "S");
+%! assert (abs (lambda(1) < 1));
+%! assert (all (abs (lambda(2:4)) >= 1));
 */
+
+OCTAVE_NAMESPACE_END
