@@ -1,25 +1,27 @@
-/*
-
-Copyright (C) 2004-2019 David Bateman
-Copyright (C) 1998-2004 Andy Adler
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1998-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -43,6 +45,8 @@ along with Octave; see the file COPYING.  If not, see
 #include "ov-cx-sparse.h"
 #include "sparse-xpow.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 static inline int
 xisint (double x)
 {
@@ -65,7 +69,7 @@ xpow (const SparseMatrix& a, double b)
   if (nr == 0 || nc == 0 || nr != nc)
     error ("for A^b, A must be a square matrix.  Use .^ for elementwise power.");
 
-  if (static_cast<int> (b) != b)
+  if (! xisint (b))
     error ("use full(a) ^ full(b)");
 
   int btmp = static_cast<int> (b);
@@ -133,7 +137,7 @@ xpow (const SparseComplexMatrix& a, double b)
   if (nr == 0 || nc == 0 || nr != nc)
     error ("for A^b, A must be a square matrix.  Use .^ for elementwise power.");
 
-  if (static_cast<int> (b) != b)
+  if (! xisint (b))
     error ("use full(a) ^ full(b)");
 
   int btmp = static_cast<int> (b);
@@ -263,7 +267,7 @@ elem_xpow (double a, const SparseMatrix& b)
           for (octave_idx_type i = 0; i < nr; i++)
             {
               octave_quit ();
-              result(i, j) = std::pow (atmp, b(i,j));
+              result(i, j) = std::pow (atmp, b(i, j));
             }
         }
 
@@ -278,7 +282,7 @@ elem_xpow (double a, const SparseMatrix& b)
           for (octave_idx_type i = 0; i < nr; i++)
             {
               octave_quit ();
-              result(i, j) = std::pow (a, b(i,j));
+              result(i, j) = std::pow (a, b(i, j));
             }
         }
 
@@ -303,7 +307,7 @@ elem_xpow (double a, const SparseComplexMatrix& b)
       for (octave_idx_type i = 0; i < nr; i++)
         {
           octave_quit ();
-          result(i, j) = std::pow (atmp, b(i,j));
+          result(i, j) = std::pow (atmp, b(i, j));
         }
     }
 
@@ -327,7 +331,7 @@ elem_xpow (const SparseMatrix& a, double b)
       octave_idx_type nr = a.rows ();
       octave_idx_type nc = a.cols ();
 
-      if (static_cast<int> (b) != b && a.any_element_is_negative ())
+      if (! xisint (b) && a.any_element_is_negative ())
         {
           ComplexMatrix result (nr, nc, Complex (std::pow (0.0, b)));
 
@@ -361,7 +365,7 @@ elem_xpow (const SparseMatrix& a, double b)
           retval = octave_value (result);
         }
     }
-  else if (static_cast<int> (b) != b && a.any_element_is_negative ())
+  else if (! xisint (b) && a.any_element_is_negative ())
     {
       SparseComplexMatrix result (a);
 
@@ -425,7 +429,7 @@ elem_xpow (const SparseMatrix& a, const SparseMatrix& b)
         if (a.data(i) < 0.0)
           {
             double btmp = b (a.ridx (i), j);
-            if (static_cast<int> (btmp) != btmp)
+            if (! xisint (btmp))
               {
                 convert_to_complex = 1;
                 goto done;
@@ -449,8 +453,8 @@ done:
           for (octave_idx_type i = a.cidx (j); i < a.cidx (j+1); i++)
             {
               octave_quit ();
-              complex_result.xelem (a.ridx (i), j) =
-                std::pow (Complex (a.data (i)), Complex (b(a.ridx (i), j)));
+              complex_result.xelem (a.ridx (i), j)
+                = std::pow (Complex (a.data (i)), Complex (b(a.ridx (i), j)));
             }
         }
       complex_result.maybe_compress (true);
@@ -597,8 +601,8 @@ elem_xpow (const SparseComplexMatrix& a, double b)
             for (octave_idx_type i = a.cidx (j); i < a.cidx (j+1); i++)
               {
                 octave_quit ();
-                result (a.ridx (i), j) =
-                  std::pow (a.data (i), static_cast<int> (b));
+                result (a.ridx (i), j)
+                  = std::pow (a.data (i), static_cast<int> (b));
               }
         }
       else
@@ -741,3 +745,5 @@ elem_xpow (const SparseComplexMatrix& a, const SparseComplexMatrix& b)
 
   return result;
 }
+
+OCTAVE_NAMESPACE_END
