@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,6 +38,8 @@
 #include "xdiv.h"
 #include "xpow.h"
 
+OCTAVE_NAMESPACE_BEGIN
+
 // scalar by matrix ops.
 
 DEFNDBINOP_OP (add, float_scalar, float_matrix, float_scalar, float_array, +)
@@ -85,7 +87,7 @@ DEFNDBINOP_FN (ne, float_scalar, float_matrix, float_scalar,
 DEFNDBINOP_OP (el_mul, float_scalar, float_matrix, float_scalar,
                float_array, *)
 DEFNDBINOP_FN (el_div, float_scalar, float_matrix, float_scalar,
-               float_array, x_el_div)
+               float_array, elem_xdiv)
 DEFNDBINOP_FN (el_pow, float_scalar, float_matrix, float_scalar,
                float_array, elem_xpow)
 
@@ -154,3 +156,5 @@ install_fs_fm_ops (octave::type_info& ti)
 
   INSTALL_WIDENOP_TI (ti, octave_float_scalar, octave_float_matrix, matrix_conv);
 }
+
+OCTAVE_NAMESPACE_END
