@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2020 The Octave Project Developers
+// Copyright (C) 2016-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -39,44 +39,44 @@
 extern "C" {
 #endif
 
-extern int octave_mkdir_wrapper (const char *name, mode_t mode);
+extern OCTAVE_API int octave_mkdir_wrapper (const char *name, mode_t mode);
 
-extern int octave_mkfifo_wrapper (const char *name, mode_t mode);
+extern OCTAVE_API int octave_mkfifo_wrapper (const char *name, mode_t mode);
 
-extern int octave_umask_wrapper (mode_t mode);
+extern OCTAVE_API int octave_umask_wrapper (mode_t mode);
 
-extern int
+extern OCTAVE_API int
 octave_stat_wrapper (const char *fname, mode_t *mode, ino_t *ino,
                      dev_t *dev, nlink_t *nlink, uid_t *uid,
                      gid_t *gid, off_t *size, time_t *atime,
                      time_t *mtime, time_t *ctime, dev_t *rdev,
                      long *blksize, long *blocks);
 
-extern int
+extern OCTAVE_API int
 octave_lstat_wrapper (const char *lname, mode_t *mode, ino_t *ino,
                       dev_t *dev, nlink_t *nlink, uid_t *uid,
                       gid_t *gid, off_t *size, time_t *atime,
                       time_t *mtime, time_t *ctime, dev_t *rdev,
                       long *blksize, long *blocks);
 
-extern int
+extern OCTAVE_API int
 octave_fstat_wrapper (int fid, mode_t *mode, ino_t *ino,
                       dev_t *dev, nlink_t *nlink, uid_t *uid,
                       gid_t *gid, off_t *size, time_t *atime,
                       time_t *mtime, time_t *ctime, dev_t *rdev,
                       long *blksize, long *blocks);
 
-extern bool octave_is_blk_wrapper (mode_t mode);
-extern bool octave_is_chr_wrapper (mode_t mode);
-extern bool octave_is_dir_wrapper (mode_t mode);
-extern bool octave_is_fifo_wrapper (mode_t mode);
-extern bool octave_is_lnk_wrapper (mode_t mode);
-extern bool octave_is_reg_wrapper (mode_t mode);
-extern bool octave_is_sock_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_blk_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_chr_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_dir_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_fifo_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_lnk_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_reg_wrapper (mode_t mode);
+extern OCTAVE_API bool octave_is_sock_wrapper (mode_t mode);
 
-extern bool octave_have_struct_stat_st_rdev (void);
-extern bool octave_have_struct_stat_st_blksize (void);
-extern bool octave_have_struct_stat_st_blocks (void);
+extern OCTAVE_API bool octave_have_struct_stat_st_rdev (void);
+extern OCTAVE_API bool octave_have_struct_stat_st_blksize (void);
+extern OCTAVE_API bool octave_have_struct_stat_st_blocks (void);
 
 #if defined __cplusplus
 }
