@@ -1,4 +1,9 @@
-## Copyright (C) 1993-2019 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1993-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {} int2str (@var{n})
@@ -51,11 +58,9 @@
 ## @seealso{sprintf, num2str, mat2str}
 ## @end deftypefn
 
-## Author: jwe
-
 function retval = int2str (n)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   elseif (! (isnumeric (n) || islogical (n) || ischar (n)))
     error ("int2str: N must be a numeric, logical, or character array");
@@ -103,6 +108,5 @@ endfunction
 %!assert (int2str ([1, 2, 3; 4, 5, 6]), ["1  2  3";"4  5  6"])
 %!assert (int2str ([]), "")
 
-%!error int2str ()
-%!error int2str (1, 2)
+%!error <Invalid call> int2str ()
 %!error <N must be a numeric> int2str ({1})
