@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2016-2021 The Octave Project Developers
+## Copyright (C) 2016-2022 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -23,7 +23,11 @@
 ##
 ########################################################################
 
-function [fun] = check_default_input (fun, trange, solver, varargin);
+function fun = check_default_input (fun, trange, solver, y0, yp0);
+
+  if (nargin < 4)
+    print_usage ();
+  endif
 
   ## Check fun
   validateattributes (fun, {"function_handle", "char"}, {}, solver, "fun");
@@ -57,7 +61,6 @@ function [fun] = check_default_input (fun, trange, solver, varargin);
   endif
 
   ## Check y0 and yp0
-  y0 = varargin{1};
   if (! isnumeric (y0) || ! isvector (y0))
     error ("Octave:invalid-input-arg",
            [solver ": Y0 must be a numeric vector"]);
@@ -65,7 +68,6 @@ function [fun] = check_default_input (fun, trange, solver, varargin);
   y0 = y0(:);
 
   if (nargin == 5)
-    yp0 = varargin{2};
     if (! isnumeric (yp0) || ! isvector (yp0))
       error ("Octave:invalid-input-arg",
              [solver ": YP0 must be a numeric vector"]);
