@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1993-2020 The Octave Project Developers
+## Copyright (C) 1993-2022 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -49,7 +49,8 @@
 ## by supplying a color matrix, @var{c}.
 ##
 ## Any property/value pairs are passed directly to the underlying surface
-## object.
+## object.  The full list of properties is documented at
+## @ref{Surface Properties}.
 ##
 ## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
@@ -57,7 +58,8 @@
 ## The optional return value @var{h} is a graphics handle to the created
 ## surface object.
 ##
-## @seealso{ezmesh, meshc, meshz, trimesh, contour, surf, surface, meshgrid, hidden, shading, colormap, caxis}
+## @seealso{ezmesh, meshc, meshz, trimesh, contour, surf, surface, meshgrid,
+## hidden, shading, colormap, caxis}
 ## @end deftypefn
 
 function h = mesh (varargin)
